==> bladoxy-1.3.0a1.tar.gz: bladoxy-1.3.0a1/bladoxy/utils/print_info.py <==
# Copyright 2024 Magicum Sidus
#
# Licensed under the Apache License, Version 2.0 (the "License"))
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


def echo_version_info():
  print(" /$$$$$$$  /$$                 /$$                              ")
  print("| $$__  $$| $$                | $$                              ")
  print("| $$  \ $$| $$  /$$$$$$   /$$$$$$$  /$$$$$$  /$$   /$$ /$$   /$$")
  print("| $$$$$$$ | $$ |____  $$ /$$__  $$ /$$__  $$|  $$ /$$/| $$  | $$")
  print("| $$__  $$| $$  /$$$$$$$| $$  | $$| $$  \ $$ \  $$$$/ | $$  | $$")
  print("| $$  \ $$| $$ /$$__  $$| $$  | $$| $$  | $$  >$$  $$ | $$  | $$")
  print("| $$$$$$$/| $$|  $$$$$$$|  $$$$$$$|  $$$$$$/ /$$/\  $$|  $$$$$$$")
  print("|_______/ |__/ \_______/ \_______/ \______/ |__/  \__/ \____  $$")
  print("                                                       /$$  | $$")
  print("                                                      |  $$$$$$/")
  print("                                                       \______/ ")



  print(" __     __ _     _____    ___           _         _            ")
  print(" \ \   / // |   |___ /   / _ \    __ _ | | _ __  | |__    __ _ ")
  print("  \ \ / / | |     |_ \  | | | |  / _` || || '_ \ | '_ \  / _` |")
  print("   \ V /  | | _  ___) |_| |_| | | (_| || || |_) || | | || (_| |")
  print("    \_/   |_|(_)|____/(_)\___/   \__,_||_|| .__/ |_| |_| \__,_|")
  print("                                          |_|                  ")


  print("     _         _   _                  __  __   ____   ")
  print("    / \  _   _| |_| |__   ___  _ __  |  \/  | / ___|  ")
  print("   / _ \| | | | __| '_ \ / _ \| '__| | |\/| | \___ \  ")
  print("  / ___ \ |_| | |_| | | | (_) | |    | |  | |_ ___) | ")
  print(" /_/   \_\__,_|\__|_| |_|\___/|_|    |_|  |_(_)____(_)")
  print("                                                      ")


if __name__ == "__main__":
    echo_version_info()

==> bladoxy-1.4.3.tar.gz: bladoxy-1.4.3/bladoxy/utils/print_info.py <==
# Copyright 2024 Magicum Sidus
#
# Licensed under the Apache License, Version 2.0 (the "License"))
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


BLADOXY_VERSION = "v1.4.3"


def echo_version_info():
  print(" /$$$$$$$  /$$                 /$$                              ")
  print("| $$__  $$| $$                | $$                              ")
  print("| $$  \ $$| $$  /$$$$$$   /$$$$$$$  /$$$$$$  /$$   /$$ /$$   /$$")
  print("| $$$$$$$ | $$ |____  $$ /$$__  $$ /$$__  $$|  $$ /$$/| $$  | $$")
  print("| $$__  $$| $$  /$$$$$$$| $$  | $$| $$  \ $$ \  $$$$/ | $$  | $$")
  print("| $$  \ $$| $$ /$$__  $$| $$  | $$| $$  | $$  >$$  $$ | $$  | $$")
  print("| $$$$$$$/| $$|  $$$$$$$|  $$$$$$$|  $$$$$$/ /$$/\  $$|  $$$$$$$")
  print("|_______/ |__/ \_______/ \_______/ \______/ |__/  \__/ \____  $$")
  print("                                                       /$$  | $$")
  print("                                                      |  $$$$$$/")
  print("                                                       \______/ ")



  print(" __     __ _    _  _      ___  ")
  print(" \ \   / // |  | || |    / _ \ ")
  print("  \ \ / / | |  | || |_  | | | |")
  print("   \ V /  | | _|__   _|_| |_| |")
  print("    \_/   |_|(_)  |_| (_)\___/ ")
  print("                               ")


  print("     _         _   _                  __  __   ____   ")
  print("    / \  _   _| |_| |__   ___  _ __  |  \/  | / ___|  ")
  print("   / _ \| | | | __| '_ \ / _ \| '__| | |\/| | \___ \  ")
  print("  / ___ \ |_| | |_| | | | (_) | |    | |  | |_ ___) | ")
  print(" /_/   \_\__,_|\__|_| |_|\___/|_|    |_|  |_(_)____(_)")
  print("                                                      ")


if __name__ == "__main__":
    echo_version_info()
